/* This file is part of Cloudy and is copyright (C)1978-2013 by Gary J. Ferland and
 * others.  For conditions of distribution and use see copyright notice in license.txt */
/*IonNelem ionization balance for elements without special cases */
#include "cddefines.h"
#include "trace.h"
#include "dense.h"
#include "ionbal.h"
#include "mole.h"
#include "oxy.h"
#include "atmdat.h"
#include "hmi.h"

/** charge exchange ionization / recombination */
void ion_CX( long nelem )
{
	DEBUG_ENTRY( "ion_CX()" );

	ASSERT( nelem < LIMELM);
	ASSERT( nelem > 1 );

	long limit = MIN2(nelem-NISO,dense.IonHigh[nelem]-1);

	for( long ion=dense.IonLow[nelem]; ion <= limit; ion++ )
	{
		/* number of bound electrons of the ion after recombination,
		 * for an atom (ion=0) this is
		 * equal to nelem+1, the element on the physical scale, since nelem is
		 * on the C scale, being 5 for carbon */

		ionbal.CX_recomb_rate_used[nelem][ion] =
			/* He0 + ion charge transfer recombination */
			atmdat.HeCharExcRecTo[nelem][ion]*
			/* following is density [cm-3] of He0 */
			dense.xIonDense[ipHELIUM][0] +
			/* H0 + ion charge transfer recombination */
			atmdat.HCharExcRecTo[nelem][ion]*
			/* following is density [cm-3] of H0 */
			dense.xIonDense[ipHYDROGEN][0];
	}

	return;
}
